==> com.liferay.dynamic.data.mapping.form.builder-3.0.6.jar: META-INF/resources/js/components/FormBuilder/FormBuilderWithLayoutProvider.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.6/js/components/FormBuilder/FormBuilderWithLayoutProvider.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-jsx', '../LayoutProvider/LayoutProvider.es', './FormBuilder.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

  var _LayoutProvider = _interopRequireDefault(require("../LayoutProvider/LayoutProvider.es"));

  var _FormBuilder = _interopRequireDefault(require("./FormBuilder.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * LayoutProvider listens to your children's events to
   * control the `pages` and make manipulations.
   * @extends Component
   */
  var LayoutProviderWithFormBuilder =
  /*#__PURE__*/
  function (_Component) {
    _inherits(LayoutProviderWithFormBuilder, _Component);

    function LayoutProviderWithFormBuilder() {
      _classCallCheck(this, LayoutProviderWithFormBuilder);

      return _possibleConstructorReturn(this, _getPrototypeOf(LayoutProviderWithFormBuilder).apply(this, arguments));
    }

    _createClass(LayoutProviderWithFormBuilder, [{
      key: "render",
      value: function render() {
        var _this$props = this.props,
            formBuilderProps = _this$props.formBuilderProps,
            layoutProviderProps = _this$props.layoutProviderProps;
        var LProvider = _LayoutProvider["default"];
        var FBuilder = _FormBuilder["default"];
        IncrementalDOM.elementOpenStart(LProvider);
        iDOMHelpers.forOwn(layoutProviderProps, iDOMHelpers.attr);
        IncrementalDOM.elementOpenEnd(LProvider);
        IncrementalDOM.elementOpenStart(FBuilder);
        iDOMHelpers.forOwn(formBuilderProps, iDOMHelpers.attr);
        IncrementalDOM.elementOpenEnd(FBuilder);
        IncrementalDOM.elementClose(FBuilder);
        return IncrementalDOM.elementClose(LProvider);
      }
    }]);

    return LayoutProviderWithFormBuilder;
  }(_metalJsx["default"]);

  var _default = LayoutProviderWithFormBuilder;
  exports["default"] = _default;
  //# sourceMappingURL=FormBuilderWithLayoutProvider.es.js.map
});
//# sourceMappingURL=FormBuilderWithLayoutProvider.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-3.0.9.jar: META-INF/resources/js/components/FormBuilder/FormBuilderWithLayoutProvider.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@3.0.9/js/components/FormBuilder/FormBuilderWithLayoutProvider.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer', 'frontend-js-metal-web$metal-jsx', 'frontend-js-metal-web$metal-state', '../LayoutProvider/LayoutProvider.es', './FormBuilder.es', './withActionableFields.es', './withEditablePageHeader.es', './withMoveableFields.es', './withMultiplePages.es', './withResizeableColumns.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _dynamicDataMappingFormRenderer = require("dynamic-data-mapping-form-renderer");

  var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _LayoutProvider = _interopRequireDefault(require("../LayoutProvider/LayoutProvider.es"));

  var _FormBuilder = require("./FormBuilder.es");

  var _withActionableFields = _interopRequireDefault(require("./withActionableFields.es"));

  var _withEditablePageHeader = _interopRequireDefault(require("./withEditablePageHeader.es"));

  var _withMoveableFields = _interopRequireDefault(require("./withMoveableFields.es"));

  var _withMultiplePages = _interopRequireDefault(require("./withMultiplePages.es"));

  var _withResizeableColumns = _interopRequireDefault(require("./withResizeableColumns.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * LayoutProvider listens to your children's events to
   * control the `pages` and make manipulations.
   * @extends Component
   */
  var FormBuilderWithLayoutProvider =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FormBuilderWithLayoutProvider, _Component);

    function FormBuilderWithLayoutProvider() {
      _classCallCheck(this, FormBuilderWithLayoutProvider);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormBuilderWithLayoutProvider).apply(this, arguments));
    }

    _createClass(FormBuilderWithLayoutProvider, [{
      key: "render",
      value: function render() {
        var _this$props = this.props,
            formBuilderProps = _this$props.formBuilderProps,
            layoutProviderProps = _this$props.layoutProviderProps,
            singlePage = _this$props.singlePage;
        var LProvider = _LayoutProvider["default"];
        var composeList = [_withActionableFields["default"], _withMoveableFields["default"], _withResizeableColumns["default"]];

        if (!singlePage) {
          composeList.push(_withMultiplePages["default"]);
          composeList.push(_withEditablePageHeader["default"]);
        }

        var FBuilder = _dynamicDataMappingFormRenderer.compose.apply(void 0, composeList)(_FormBuilder.FormBuilderBase);

        IncrementalDOM.elementOpenStart(LProvider);
        iDOMHelpers.forOwn(layoutProviderProps, iDOMHelpers.attr);
        IncrementalDOM.elementOpenEnd(LProvider);
        IncrementalDOM.elementOpenStart(FBuilder);
        iDOMHelpers.forOwn(formBuilderProps, iDOMHelpers.attr);
        IncrementalDOM.elementOpenEnd(FBuilder);
        IncrementalDOM.elementClose(FBuilder);
        return IncrementalDOM.elementClose(LProvider);
      }
    }]);

    return FormBuilderWithLayoutProvider;
  }(_metalJsx["default"]);

  FormBuilderWithLayoutProvider.PROPS = {
    formBuilderProps: _metalState.Config.object(),
    layoutProviderProps: _metalState.Config.object()
  };
  var _default = FormBuilderWithLayoutProvider;
  exports["default"] = _default;
  //# sourceMappingURL=FormBuilderWithLayoutProvider.es.js.map
});
//# sourceMappingURL=FormBuilderWithLayoutProvider.es.js.map
